@@ -41,7 +41,7 @@ Bool IsClick(int x,int y,unsigned EndMask, XEvent *d)
         (y - ycurrent < 3)&&(y - ycurrent > -3)&&
 	((lastTimestamp - t0) < Scr.ClickTime))
     {
-      sleep_a_little(20000);
+      usleep(20000);
       total+=20;
       if(XCheckMaskEvent (dpy,EndMask, d))
 	{
@@ -186,7 +186,7 @@ void ComplexFunction(XEvent *eventp,Window w,FvwmWindow *tmp_win,
 
   if(!GrabEm(SELECT))
     {
-      XBell(dpy,Scr.screen);
+      XBell(dpy, 0);
       for(i=0;i<10;i++)
 	  if(arguments[i] != NULL)free(arguments[i]);
       return;
