@@ -56,11 +56,9 @@ it should not be an option, once it works right. HEDU 2/2/94 */
 
 #include <X11/Intrinsic.h>
 
-#ifdef SIGNALRETURNSINT
-#define SIGNAL_T int
+#if RETSIGTYPE != void
 #define SIGNAL_RETURN return 0
 #else
-#define SIGNAL_T void
 #define SIGNAL_RETURN return
 #endif
 
@@ -126,6 +124,22 @@ typedef struct ColorPair
 struct FvwmDecor;		/* definition in screen.h */
 #endif
 
+/*
+  For 1 style statement, there can be any number of IconBoxes.
+  The name list points at the first one in the chain.
+ */
+typedef struct icon_boxes_struct {
+  struct icon_boxes_struct *next;       /* next icon_boxes or zero */
+  int IconBox[4];                       /* x/y x/y for iconbox */
+  short IconGrid[2];                    /* x incr, y incr */
+  unsigned char IconFlags;               /* some bits */
+  /* IconFill only takes 3 bits.  Defaults are top, left, vert co-ord first */
+  /* eg: t l = 0,0,0; l t = 0,0,1; b r = 1,1,0 */
+#define ICONFILLBOT (1<<0)
+#define ICONFILLRGT (1<<1)
+#define ICONFILLHRZ (1<<2)
+} icon_boxes;
+
 /* for each window that is on the display, one of these structures
  * is allocated and linked into a list 
  */
@@ -212,8 +226,7 @@ typedef struct FvwmWindow
     Pixel TextPixel;
     Pixel BackPixel;
     unsigned long buttons;
-    int IconBox[4];
-    int BoxFillMethod;
+    icon_boxes *IconBoxes;              /* zero or more iconboxes */
 } FvwmWindow;
 
 /***************************************************************************
