@@ -1,6 +1,6 @@
 /****************************************************************************
  * This module is mostly all new
- * by Rob Nation 
+ * by Rob Nation
  * A little of it is borrowed from ctwm.
  * Copyright 1993 Robert Nation. No restrictions are placed on this code,
  * as long as the copyright notice is preserved
@@ -58,7 +58,7 @@ void CreateIconWindow(FvwmWindow *tmp_win, int def_x, int def_y)
   tmp_win->icon_pixmap_w = None;
   tmp_win->iconPixmap = None;
   tmp_win->iconDepth = 0;
-  
+
   if(tmp_win->flags & SUPPRESSICON)
     return;
 
@@ -89,7 +89,7 @@ void CreateIconWindow(FvwmWindow *tmp_win, int def_x, int def_y)
   if (!(tmp_win->flags & NOICON_TITLE)||(tmp_win->icon_p_height == 0))
     {
       tmp_win->icon_t_width = XTextWidth(Scr.IconFont.font,
-					 tmp_win->icon_name, 
+					 tmp_win->icon_name,
                                          strlen(tmp_win->icon_name));
       tmp_win->icon_w_height = ICON_HEIGHT;
     }
@@ -114,7 +114,7 @@ void CreateIconWindow(FvwmWindow *tmp_win, int def_x, int def_y)
     final_x = 0;
   if(final_y <0)
     final_y = 0;
-  
+
   if(final_x + tmp_win->icon_w_width >=Scr.MyDisplayWidth)
     final_x = Scr.MyDisplayWidth - tmp_win->icon_w_width-1;
   if(final_y + tmp_win->icon_w_height >=Scr.MyDisplayHeight)
@@ -129,28 +129,28 @@ void CreateIconWindow(FvwmWindow *tmp_win, int def_x, int def_y)
   valuemask =  CWBorderPixel | CWCursor | CWEventMask | CWBackPixel;
   attributes.border_pixel = Scr.MenuColors.fore;
   attributes.cursor = Scr.FvwmCursors[DEFAULT];
-  attributes.event_mask = (ButtonPressMask | ButtonReleaseMask | 
+  attributes.event_mask = (ButtonPressMask | ButtonReleaseMask |
 			   VisibilityChangeMask |
 			   ExposureMask | KeyPressMask|EnterWindowMask |
 			   FocusChangeMask );
   if (!(tmp_win->flags & NOICON_TITLE)||(tmp_win->icon_p_height == 0))
-    tmp_win->icon_w = 
+    tmp_win->icon_w =
       XCreateWindow(dpy, Scr.Root, final_x, final_y+tmp_win->icon_p_height,
                     tmp_win->icon_w_width, tmp_win->icon_w_height,0,
-                    CopyFromParent, 
+                    CopyFromParent,
                     CopyFromParent,CopyFromParent,valuemask,&attributes);
-  
+
   if((tmp_win->flags & ICON_OURS)&&(tmp_win->icon_p_width>0)&&
      (tmp_win->icon_p_height>0))
     {
-      tmp_win->icon_pixmap_w = 
+      tmp_win->icon_pixmap_w =
 	XCreateWindow(dpy, Scr.Root, final_x, final_y, tmp_win->icon_p_width,
 		      tmp_win->icon_p_height, 0, CopyFromParent,
 		      CopyFromParent,CopyFromParent,valuemask,&attributes);
     }
   else
     {
-      attributes.event_mask = (ButtonPressMask | ButtonReleaseMask | 
+      attributes.event_mask = (ButtonPressMask | ButtonReleaseMask |
 			       VisibilityChangeMask |
 			       KeyPressMask|EnterWindowMask |
 			       FocusChangeMask | LeaveWindowMask );
@@ -210,7 +210,7 @@ void DrawIconWindow(FvwmWindow *Tmp_win)
   if(Scr.Hilite == Tmp_win)
     {
       if(Scr.d_depth < 2) {
-	  Relief = 
+	  Relief =
 	      Shadow = Scr.DefaultDecor.HiShadowGC;
 	  TextColor = Scr.DefaultDecor.HiColors.fore;
 	  BackColor = Scr.DefaultDecor.HiColors.back;
@@ -226,7 +226,7 @@ void DrawIconWindow(FvwmWindow *Tmp_win)
           Tmp_win->icon_w_width = Tmp_win->icon_t_width+6;
           if(Tmp_win->icon_w_width < Tmp_win->icon_p_width)
             Tmp_win->icon_w_width = Tmp_win->icon_p_width;
-          Tmp_win->icon_xl_loc = Tmp_win->icon_x_loc - 
+          Tmp_win->icon_xl_loc = Tmp_win->icon_x_loc -
             (Tmp_win->icon_w_width - Tmp_win->icon_p_width)/2;
           /* start keep label on screen. dje 8/7/97 */
           if (Tmp_win->icon_xl_loc < 0) {  /* if new loc neg (off left edge) */
@@ -253,11 +253,11 @@ void DrawIconWindow(FvwmWindow *Tmp_win)
 	{
 	  Globalgcv.foreground = Tmp_win->ReliefPixel;
 	  Globalgcm = GCForeground;
-	  XChangeGC(dpy,Scr.ScratchGC1,Globalgcm,&Globalgcv); 
+	  XChangeGC(dpy,Scr.ScratchGC1,Globalgcm,&Globalgcv);
 	  Relief = Scr.ScratchGC1;
-	  
+
 	  Globalgcv.foreground = Tmp_win->ShadowPixel;
-	  XChangeGC(dpy,Scr.ScratchGC2,Globalgcm,&Globalgcv); 
+	  XChangeGC(dpy,Scr.ScratchGC2,Globalgcm,&Globalgcv);
 	  Shadow = Scr.ScratchGC2;
 	}
       /* resize the icon name window */
@@ -268,7 +268,7 @@ void DrawIconWindow(FvwmWindow *Tmp_win)
         }
       TextColor = Tmp_win->TextPixel;
       BackColor = Tmp_win->BackPixel;
-	  
+
     }
   if((Tmp_win->flags & ICON_OURS)&&(Tmp_win->icon_pixmap_w != None))
     XSetWindowBackground(dpy,Tmp_win->icon_pixmap_w,
@@ -288,14 +288,14 @@ void DrawIconWindow(FvwmWindow *Tmp_win)
       XMoveResizeWindow(dpy, Tmp_win->icon_w, Tmp_win->icon_xl_loc,
                         Tmp_win->icon_y_loc+Tmp_win->icon_p_height,
                         Tmp_win->icon_w_width,ICON_HEIGHT);
-      
+
       XClearWindow(dpy,Tmp_win->icon_w);
     }
-  
+
   if((Tmp_win->iconPixmap != None)&&(!(Tmp_win->flags & SHAPED_ICON)))
     RelieveWindow(Tmp_win,Tmp_win->icon_pixmap_w,0,0,
-		  Tmp_win->icon_p_width, Tmp_win->icon_p_height, 
-		  Relief,Shadow, FULL_HILITE);  
+		  Tmp_win->icon_p_width, Tmp_win->icon_p_height,
+		  Relief,Shadow, FULL_HILITE);
 
   /* need to locate the icon pixmap */
   if(Tmp_win->iconPixmap != None)
@@ -307,20 +307,20 @@ void DrawIconWindow(FvwmWindow *Tmp_win)
 	}
       else
 	XCopyPlane(dpy,Tmp_win->iconPixmap,Tmp_win->icon_pixmap_w,Scr.ScratchGC3,0,
-		   0,Tmp_win->icon_p_width-4, Tmp_win->icon_p_height-4,2,2,1);  
-    }      
+		   0,Tmp_win->icon_p_width-4, Tmp_win->icon_p_height-4,2,2,1);
+    }
 
   if(Tmp_win->icon_w != None)
     {
       /* text position */
       x = (Tmp_win->icon_w_width - Tmp_win->icon_t_width)/2;
       if(x<3)x=3;
-      
+
       XDrawString (dpy, Tmp_win->icon_w, Scr.ScratchGC3, x,
                    Tmp_win->icon_w_height-Scr.IconFont.height+
 		   Scr.IconFont.y-3,
                    Tmp_win->icon_name, strlen(Tmp_win->icon_name));
-      RelieveWindow(Tmp_win,Tmp_win->icon_w,0,0,Tmp_win->icon_w_width,      
+      RelieveWindow(Tmp_win,Tmp_win->icon_w,0,0,Tmp_win->icon_w_width,
                     ICON_HEIGHT,Relief,Shadow, FULL_HILITE);
     }
 }
@@ -339,8 +339,8 @@ void RedoIconName(FvwmWindow *Tmp_win)
 
   if (Tmp_win->icon_w == (int)NULL)
     return;
-  
-  Tmp_win->icon_t_width = XTextWidth(Scr.IconFont.font,Tmp_win->icon_name, 
+
+  Tmp_win->icon_t_width = XTextWidth(Scr.IconFont.font,Tmp_win->icon_name,
 				     strlen(Tmp_win->icon_name));
   /* clear the icon window, and trigger a re-draw via an expose event */
   if (Tmp_win->flags & ICONIFIED)
@@ -350,7 +350,7 @@ void RedoIconName(FvwmWindow *Tmp_win)
 
 
 
-  
+
  /***********************************************************************
  *
  *  Procedure:
@@ -436,7 +436,7 @@ void AutoPlace(FvwmWindow *t)
     width = t->icon_p_width;          /* unnecessary copy of width */
     height = t->icon_w_height + t->icon_p_height; /* total height */
     loc_ok = False;                   /* no slot found yet */
-    
+
     /* check all boxes in order */
     for(icon_boxes_ptr= t->IconBoxes;   /* init */
         icon_boxes_ptr != NULL; /* until no more boxes */
@@ -539,7 +539,7 @@ void AutoPlace(FvwmWindow *t)
                   test_window->icon_w_height;
                 tx = test_window->icon_x_loc;
                 ty = test_window->icon_y_loc;
-                
+
                 if((tx<(real_x+width+3))&&((tx+tw+3) > real_x)&&
                    (ty<(real_y+height+3))&&((ty+th + 3)>real_y)) {
                   loc_ok = False;         /* don't accept this location */
@@ -557,23 +557,24 @@ void AutoPlace(FvwmWindow *t)
       return;                         /* just leave it */
     t->icon_x_loc = real_x;
     t->icon_y_loc = real_y;
-    
+
     if(t->icon_pixmap_w)
       XMoveWindow(dpy,t->icon_pixmap_w,t->icon_x_loc, t->icon_y_loc);
-    
+
     t->icon_w_width = t->icon_p_width;
     t->icon_xl_loc = t->icon_x_loc;
-    
+
     if (t->icon_w != None)
       XMoveResizeWindow(dpy, t->icon_w, t->icon_xl_loc,
-                        t->icon_y_loc+t->icon_p_height, 
+                        t->icon_y_loc+t->icon_p_height,
                         t->icon_w_width,ICON_HEIGHT);
-    Broadcast(M_ICON_LOCATION,7,t->w,t->frame,
-              (unsigned long)t,
-              t->icon_x_loc,t->icon_y_loc,
-              t->icon_w_width, t->icon_w_height+ t->icon_p_height);
+    BroadcastPacket(M_ICON_LOCATION, 7,
+                    t->w, t->frame,
+                    (unsigned long)t,
+                    t->icon_x_loc, t->icon_y_loc,
+                    t->icon_w_width, t->icon_w_height+t->icon_p_height);
   }
-  
+
 }
 
 /***********************************************************************
@@ -596,27 +597,27 @@ void GrabIconButtons(FvwmWindow *tmp_win, Window w)
 	 (MouseEntry->IsMouse == 1))
 	{
 	  if(MouseEntry->Button_Key >0)
-	    XGrabButton(dpy, MouseEntry->Button_Key, MouseEntry->Modifier, w, 
+	    XGrabButton(dpy, MouseEntry->Button_Key, MouseEntry->Modifier, w,
 			True, ButtonPressMask | ButtonReleaseMask,
-			GrabModeAsync, GrabModeAsync, None, 
+			GrabModeAsync, GrabModeAsync, None,
 			Scr.FvwmCursors[DEFAULT]);
 	  else
 	    {
 	      XGrabButton(dpy, 1, MouseEntry->Modifier, w,
 			  True, ButtonPressMask | ButtonReleaseMask,
-			  GrabModeAsync, GrabModeAsync, None, 
+			  GrabModeAsync, GrabModeAsync, None,
 			  Scr.FvwmCursors[DEFAULT]);
 	      XGrabButton(dpy, 2, MouseEntry->Modifier, w,
 			  True, ButtonPressMask | ButtonReleaseMask,
-			  GrabModeAsync, GrabModeAsync, None, 
+			  GrabModeAsync, GrabModeAsync, None,
 			  Scr.FvwmCursors[DEFAULT]);
 	      XGrabButton(dpy, 3, MouseEntry->Modifier, w,
 			  True, ButtonPressMask | ButtonReleaseMask,
-			  GrabModeAsync, GrabModeAsync, None, 
+			  GrabModeAsync, GrabModeAsync, None,
 			  Scr.FvwmCursors[DEFAULT]);
 	    }
 	}
-      
+
       MouseEntry = MouseEntry->NextBinding;
     }
   return;
@@ -661,15 +662,15 @@ void GetBitmapFile(FvwmWindow *tmp_win)
 
   if(path == NULL)return;
   if(XReadBitmapFile (dpy, Scr.Root,path,
-		      (unsigned int *)&tmp_win->icon_p_width, 
-		      (unsigned int *)&tmp_win->icon_p_height, 
+		      (unsigned int *)&tmp_win->icon_p_width,
+		      (unsigned int *)&tmp_win->icon_p_height,
 		      &tmp_win->iconPixmap,
 		      &HotX, &HotY) != BitmapSuccess)
     {
       tmp_win->icon_p_width = 0;
       tmp_win->icon_p_height = 0;
     }
-    
+
   free(path);
 }
 
@@ -689,7 +690,7 @@ void GetXPMFile(FvwmWindow *tmp_win)
   int rc;
 
   path = findIconFile(tmp_win->icon_bitmap_file, PixmapPath,R_OK);
-  if(path == NULL)return;  
+  if(path == NULL)return;
 
   XGetWindowAttributes(dpy,Scr.Root,&root_attr);
   xpm_attributes.colormap = root_attr.colormap;
@@ -704,8 +705,8 @@ void GetXPMFile(FvwmWindow *tmp_win)
   }
   color_reduce_pixmap(&my_image,Scr.ColorLimit);
   rc = XpmCreatePixmapFromXpmImage(dpy,Scr.Root, &my_image,
-                                   &tmp_win->iconPixmap, 
-                                   &tmp_win->icon_maskPixmap, 
+                                   &tmp_win->iconPixmap,
+                                   &tmp_win->icon_maskPixmap,
                                    &xpm_attributes);
   if (rc != XpmSuccess) {
     fvwm_msg(ERR,"GetXPMFile",
@@ -733,9 +734,9 @@ void GetIconWindow(FvwmWindow *tmp_win)
 {
   /* We are guaranteed that wmhints is non-null when calling this
    * routine */
-  if(XGetGeometry(dpy,   tmp_win->wmhints->icon_window, &JunkRoot, 
-		  &JunkX, &JunkY,(unsigned int *)&tmp_win->icon_p_width, 
-		  (unsigned int *)&tmp_win->icon_p_height, 
+  if(XGetGeometry(dpy,   tmp_win->wmhints->icon_window, &JunkRoot,
+		  &JunkX, &JunkY,(unsigned int *)&tmp_win->icon_p_width,
+		  (unsigned int *)&tmp_win->icon_p_height,
 		  &JunkBW, &JunkDepth)==0)
     {
       fvwm_msg(ERR,"GetIconWindow","Help! Bad Icon Window!");
@@ -776,7 +777,7 @@ void GetIconBitmap(FvwmWindow *tmp_win)
   /* We are guaranteed that wmhints is non-null when calling this
    * routine */
   XGetGeometry(dpy, tmp_win->wmhints->icon_pixmap, &JunkRoot, &JunkX, &JunkY,
-	       (unsigned int *)&tmp_win->icon_p_width, 
+	       (unsigned int *)&tmp_win->icon_p_width,
 	       (unsigned int *)&tmp_win->icon_p_height, &JunkBW, &JunkDepth);
   tmp_win->iconPixmap = tmp_win->wmhints->icon_pixmap;
   tmp_win->iconDepth = JunkDepth;
@@ -811,26 +812,26 @@ void DeIconify(FvwmWindow *tmp_win)
   /* now de-iconify transients */
   for (t = Scr.FvwmRoot.next; t != NULL; t = t->next)
     {
-      if ((t == tmp_win)|| 
+      if ((t == tmp_win)||
 	  ((t->flags & TRANSIENT) &&(t->transientfor == tmp_win->w)))
 	{
 	  t->flags |= MAPPED;
 	  if(Scr.Hilite == t)
 	    SetBorder (t, False,True,True,None);
-          
+
           /* AS stuff starts here dje */
-          if (t->icon_pixmap_w) 
+          if (t->icon_pixmap_w)
             XUnmapWindow(dpy, t->icon_pixmap_w);
-	  if (t->icon_w) 
+	  if (t->icon_w)
 	    XUnmapWindow(dpy, t->icon_w);
           XFlush(dpy);
-	  Broadcast_v(M_DEICONIFY,11,t->w,t->frame,(unsigned long)t,
-                      t->icon_x_loc,
-                      t->icon_y_loc,
-                      t->icon_p_width,
-                      t->icon_w_height+t->icon_p_height, /* dje add w_height */
-                      t->frame_x,t->frame_y,
-                      t->frame_width,t->frame_height);
+	  BroadcastPacket(M_DEICONIFY, 11,
+                          t->w, t->frame,
+                          (unsigned long)t,
+                          t->icon_x_loc, t->icon_y_loc,
+                          t->icon_p_width, t->icon_p_height+t->icon_w_height,
+                          t->frame_x, t->frame_y,
+                          t->frame_width, t->frame_height);
           /* End AS */
 	  XMapWindow(dpy, t->w);
 	  if(t->Desk == Scr.CurrentDesk)
@@ -913,15 +914,16 @@ void Iconify(FvwmWindow *tmp_win, int def_x, int def_y)
 	    {
 	      t->flags |= ICONIFIED|ICON_UNMAPPED;
 
-	      Broadcast(M_ICONIFY,7,t->w,t->frame,
-			(unsigned long)t,
-			-10000, -10000,
-			t->icon_w_width, 
-			t->icon_w_height+t->icon_p_height);
+	      BroadcastPacket(M_ICONIFY, 7,
+                              t->w, t->frame,
+                              (unsigned long)t,
+                              -10000, -10000,
+                              t->icon_w_width,
+                              t->icon_w_height+t->icon_p_height);
 	      BroadcastConfig(M_CONFIGURE_WINDOW,t);
 	    }
 	}
-    } 
+    }
   if (tmp_win->icon_w == None)
     if(tmp_win->flags & ICON_MOVED)
       CreateIconWindow(tmp_win,tmp_win->icon_x_loc,tmp_win->icon_y_loc);
@@ -931,25 +933,26 @@ void Iconify(FvwmWindow *tmp_win, int def_x, int def_y)
   /* if no pixmap we want icon width to change to text width every iconify */
   if( (tmp_win->icon_w != None) && (tmp_win->icon_pixmap_w == None) ) {
     tmp_win->icon_t_width =
-      XTextWidth(Scr.IconFont.font,tmp_win->icon_name, 
+      XTextWidth(Scr.IconFont.font,tmp_win->icon_name,
                  strlen(tmp_win->icon_name));
     tmp_win->icon_p_width = tmp_win->icon_t_width+6;
-    tmp_win->icon_w_width = tmp_win->icon_p_width; 
+    tmp_win->icon_w_width = tmp_win->icon_p_width;
   }
 
   AutoPlace(tmp_win);
   tmp_win->flags |= ICONIFIED;
   tmp_win->flags &= ~ICON_UNMAPPED;
-  Broadcast_v(M_ICONIFY,11,             /* iconify, num parms */
-            tmp_win->w,tmp_win->frame,(unsigned long)tmp_win,
-	    tmp_win->icon_x_loc,
-            tmp_win->icon_y_loc,
-	    tmp_win->icon_w_width, 
-	    tmp_win->icon_w_height+tmp_win->icon_p_height,
-            tmp_win->frame_x, /* next 4 added for Animate module */
-            tmp_win->frame_y,
-            tmp_win->frame_width,
-            tmp_win->frame_height);
+  BroadcastPacket(M_ICONIFY, 11,
+                  tmp_win->w, tmp_win->frame,
+                  (unsigned long)tmp_win,
+                  tmp_win->icon_x_loc,
+                  tmp_win->icon_y_loc,
+                  tmp_win->icon_w_width,
+                  tmp_win->icon_w_height+tmp_win->icon_p_height,
+                  tmp_win->frame_x, /* next 4 added for Animate module */
+                  tmp_win->frame_y,
+                  tmp_win->frame_width,
+                  tmp_win->frame_height);
   BroadcastConfig(M_CONFIGURE_WINDOW,tmp_win);
 
   LowerWindow(tmp_win);
@@ -957,7 +960,7 @@ void Iconify(FvwmWindow *tmp_win, int def_x, int def_y)
     {
       if (tmp_win->icon_w != None)
         XMapWindow(dpy, tmp_win->icon_w);
-      
+
       if(tmp_win->icon_pixmap_w != None)
 	XMapWindow(dpy, tmp_win->icon_pixmap_w);
       KeepOnTop();
@@ -991,12 +994,12 @@ void Iconify(FvwmWindow *tmp_win, int def_x, int def_y)
 void SetMapStateProp(FvwmWindow *tmp_win, int state)
 {
   unsigned long data[2];		/* "suggested" by ICCCM version 1 */
-  
+
   data[0] = (unsigned long) state;
   data[1] = (unsigned long) tmp_win->icon_w;
 /*  data[2] = (unsigned long) tmp_win->icon_pixmap_w;*/
-  
-  XChangeProperty (dpy, tmp_win->w, _XA_WM_STATE, _XA_WM_STATE, 32, 
+
+  XChangeProperty (dpy, tmp_win->w, _XA_WM_STATE, _XA_WM_STATE, 32,
 		   PropModeReplace, (unsigned char *) data, 2);
   return;
 }
