@@ -1,13 +1,13 @@
 /*****************************************************************************
- * This module is all original code 
- * by Rob Nation 
+ * This module is all original code
+ * by Rob Nation
  * Copyright 1993, Robert Nation
  *     You may use this code for any purpose, as long as the original
  *     copyright remains in the source code and all documentation
  ****************************************************************************/
 
 /* Almost a complete rewrite by
-   Greg J. Badros, Apr 6, Apr 16-19, 1997 
+   Greg J. Badros, Apr 6, Apr 16-19, 1997
    gjb@cs.washington.edu
 
    Fixed bugs w/ Escape leaving a menu item highlighted the next
@@ -29,7 +29,7 @@
    (some cosmetic bugs and two or three coredumps). Rewrote large parts
    of MenuInteraction and FPopupMenus.
    */
-    
+
 
 /***********************************************************************
  *
@@ -138,7 +138,7 @@ MenuStatus do_menu(MenuRoot *menu, MenuRoot *menuPrior,
   Bool fWasAlreadyPopped = FALSE;
   Bool key_press;
   Bool fDoubleClick = FALSE;
-  Time t0;
+  Time t0 = lastTimestamp;
   extern Time lastTimestamp;
   static int cindirectDeep = 0;
 
@@ -185,9 +185,8 @@ MenuStatus do_menu(MenuRoot *menu, MenuRoot *menuPrior,
     } else {
       /* we're a top level menu */
       mouse_moved = FALSE;
-      t0 = lastTimestamp;
       if(!GrabEm(MENU)) { /* GrabEm specifies the cursor to use */
-	XBell(dpy,Scr.screen);
+	XBell(dpy, 0);
 	return MENU_ABORTED;
       }
       if ((pops->flags & MENU_HAS_POSHINTS) && !fIgnorePosHints) {
@@ -204,7 +203,7 @@ MenuStatus do_menu(MenuRoot *menu, MenuRoot *menuPrior,
     /* it might also move menuPrior out of the way */
     if (!FPopupMenu (menu, menuPrior, x, y, key_press /* warp */, pops)) {
       fFailedPopup = TRUE;
-      XBell (dpy, Scr.screen);
+      XBell (dpy, 0);
     }
   }
   else {
@@ -371,7 +370,7 @@ Bool FMenuMapped(MenuRoot *menu)
   return (win_attribs.map_state == IsViewable);
 }
 
-static 
+static
 MenuItem *MiFromMenuIndex(MenuRoot *mr, int index)
 {
   int i = -1;
@@ -426,9 +425,9 @@ MenuStatus menuShortcuts(MenuRoot *menu,XEvent *Event,MenuItem **pmiCurrent)
   dkp_timestamp = 0;
   /* Is it okay to treat keysym-s as Ascii? */
   /* No, because the keypad numbers don't work. Use XlookupString */
-  index = XLookupString(Event, &keychar, 1, &keysym, NULL);
+  index = XLookupString(&(Event->xkey), &keychar, 1, &keysym, NULL);
   /* Try to match hot keys */
-  if (index == 1 && isgraph((int)keychar) && fControlKey == FALSE) { 
+  if (index == 1 && isgraph((int)keychar) && fControlKey == FALSE) {
     /* allow any printable character to be a keysym, but be sure control
        isn't pressed */
     MenuItem *mi;
@@ -465,14 +464,14 @@ MenuStatus menuShortcuts(MenuRoot *menu,XEvent *Event,MenuItem **pmiCurrent)
     case XK_h: /* vi left */
       return MENU_POPDOWN;
       break;
-      
+
     case XK_Right:
     case XK_f: /* forward */
     case XK_l: /* vi right */
       if (IS_POPUP_MENU_ITEM(miCurrent))
 	return MENU_POPUP;
       break;
-      
+
     case XK_Up:
     case XK_k: /* vi up */
     case XK_p: /* prior */
@@ -483,7 +482,7 @@ MenuStatus menuShortcuts(MenuRoot *menu,XEvent *Event,MenuItem **pmiCurrent)
 	  return MENU_NOP;
       }
       if (isgraph(keysym))
-	fControlKey = FALSE; /* don't use control modifier 
+	fControlKey = FALSE; /* don't use control modifier
 				for k or p, since those might
 				be shortcuts too-- C-k, C-p will
 				always work to do a single up */
@@ -500,7 +499,7 @@ MenuStatus menuShortcuts(MenuRoot *menu,XEvent *Event,MenuItem **pmiCurrent)
       if (newItem) {
 	*pmiCurrent = newItem;
 	return MENU_NEWITEM;
-      } else 
+      } else
 	return MENU_NOP;
       break;
 
@@ -533,16 +532,16 @@ MenuStatus menuShortcuts(MenuRoot *menu,XEvent *Event,MenuItem **pmiCurrent)
       if (newItem) {
 	*pmiCurrent = newItem;
 	return MENU_NEWITEM;
-      } else 
+      } else
 	return MENU_NOP;
       break;
-      
+
       /* Nothing special --- Allow other shortcuts */
     default:
       Keyboard_shortcuts(Event,ButtonRelease);
       break;
     }
-  
+
   return MENU_NOP;
 }
 
@@ -557,7 +556,7 @@ int c10msDelaysBeforePopup = 15;
  *      return to old sub menus, etc.
  *  Input
  *      sticks = 0, transient style menu, drops on button release
- *      sticks = 1, sticky style, stays up on a click (i.e. initial release 
+ *      sticks = 1, sticky style, stays up on a click (i.e. initial release
  *                  comes soon after initial press.
  *  Returns:
  *      MENU_ERROR on error condition
@@ -594,6 +593,9 @@ MenuStatus MenuInteraction(MenuRoot *menu,MenuRoot *menuPrior,
   Bool fPopdown = FALSE;
   Bool fPopup   = FALSE;
   Bool fDoMenu  = FALSE;
+  Bool fMotionFirst = FALSE;
+  Bool fReleaseFirst = FALSE;
+  Bool fFakedMotion = FALSE;
 
   mops.flags = 0;
   /* remember where the pointer was so we can tell if it has moved */
@@ -607,12 +609,13 @@ MenuStatus MenuInteraction(MenuRoot *menu,MenuRoot *menuPrior,
       if (fForceReposition) {
 	Event.type = MotionNotify;
 	Event.xmotion.time = lastTimestamp;
+	fFakedMotion = TRUE;
 	fForceReposition = FALSE;
       } else if (DELAY_POPUP_MENUS) {
 	while (XCheckMaskEvent(dpy,
 			       ButtonPressMask|ButtonReleaseMask|
 			       ExposureMask|KeyPressMask|VisibilityChangeMask|
-			       ButtonMotionMask, 
+			       ButtonMotionMask,
 			       &Event) == FALSE) {
 	  usleep(MICRO_S_FOR_10MS);
  	  if (c10msDelays++ == c10msDelaysBeforePopup) {
@@ -620,18 +623,19 @@ MenuStatus MenuInteraction(MenuRoot *menu,MenuRoot *menuPrior,
 	    /* fake a motion event, and set fDoPopupNow */
 	    Event.type = MotionNotify;
 	    Event.xmotion.time = lastTimestamp;
+	    fFakedMotion = TRUE;
 	    fDoPopupNow = TRUE;
 	    break;
 	  }
 	}
       } else {  /* block until there is an event */
-	XMaskEvent(dpy, 
-		   ButtonPressMask|ButtonReleaseMask|ExposureMask | 
-		   KeyPressMask|VisibilityChangeMask|ButtonMotionMask, 
+	XMaskEvent(dpy,
+		   ButtonPressMask|ButtonReleaseMask|ExposureMask |
+		   KeyPressMask|VisibilityChangeMask|ButtonMotionMask,
 		   &Event);
       }
       /*DBUG("MenuInteraction","mrPopup=%s",mrPopup?mrPopup->name:"(none)");*/
-      
+
       StashEventTime(&Event);
       if (Event.type == MotionNotify) {
 	/* discard any extra motion events before a release */
@@ -643,9 +647,10 @@ MenuStatus MenuInteraction(MenuRoot *menu,MenuRoot *menuPrior,
 	{
 	case ButtonRelease:
 	  mi = FindEntry(&x_offset);
-	  /* hold the menu up when the button is released 
+	  /* hold the menu up when the button is released
 	     for the first time if released OFF of the menu */
-	  if(fSticks) {
+	  if(fSticks && !fMotionFirst) {
+	    fReleaseFirst = TRUE;
 	    fSticks = FALSE;
 	    continue;
 	    /* break; */
@@ -653,13 +658,13 @@ MenuStatus MenuInteraction(MenuRoot *menu,MenuRoot *menuPrior,
 	  retval = mi?MENU_SELECTED:MENU_ABORTED;
 	  dkp_timestamp = 0;
 	  goto DO_RETURN;
-	  
+
 	case ButtonPress:
 	  /* if the first event is a button press allow the release to
 	     select something */
 	  fSticks = FALSE;
 	  continue;
-	  
+
 	case VisibilityNotify:
 	  continue;
 
@@ -669,7 +674,7 @@ MenuStatus MenuInteraction(MenuRoot *menu,MenuRoot *menuPrior,
 	  x_offset = 0;
 	  retval = menuShortcuts(menu,&Event,&mi);
 	  if (retval == MENU_POPDOWN ||
-	      retval == MENU_ABORTED || 
+	      retval == MENU_ABORTED ||
 	      retval == MENU_SELECTED)
 	    goto DO_RETURN;
 	  /* now warp to the new menu-item, if any */
@@ -683,7 +688,7 @@ MenuStatus MenuInteraction(MenuRoot *menu,MenuRoot *menuPrior,
 	    break;
 	  }
 	  break;
-	  
+
 	case MotionNotify:
 	  if (mouse_moved == FALSE) {
 	    int x_root, y_root;
@@ -697,8 +702,11 @@ MenuStatus MenuInteraction(MenuRoot *menu,MenuRoot *menuPrior,
 	    }
 	  }
 	  mi = FindEntry(&x_offset);
+	  if (!fReleaseFirst && !fFakedMotion)
+	    fMotionFirst = TRUE;
+	  fFakedMotion = FALSE;
 	  break;
-	  
+
 	case Expose:
 	  /* grab our expose events, let the rest go through */
 	  if((XFindContext(dpy, Event.xany.window,MenuContext,
@@ -714,7 +722,7 @@ MenuStatus MenuInteraction(MenuRoot *menu,MenuRoot *menuPrior,
 				  Tmp_win and messes up our calls to
 				  check_allowed_function for stippling
 				  disallowed menu items */
-	  
+
 	default:
 	  DispatchEvent();
 	  if (s_Tmp_win)
@@ -732,8 +740,6 @@ MenuStatus MenuInteraction(MenuRoot *menu,MenuRoot *menuPrior,
 	/* we're on a menu item */
 	fOffMenuAllowed = FALSE;
 	mr = mi->mr;
-	/* get pos hints for item's action */
-	GetPopupOptions(mi,&mops);
 
 	if (mr != menu && mr != mrPopup && mr != MrPopupForMi(mi)) {
 	  /* we're on an item from a prior menu */
@@ -748,7 +754,7 @@ MenuStatus MenuInteraction(MenuRoot *menu,MenuRoot *menuPrior,
 	  c10msDelays = 0;
 	  /* we're on the same menu, but a different item,
 	     so we need to unselect the old item */
-	  if (menu->selected) { 
+	  if (menu->selected) {
 	    /* something else was already selected on this menu */
 	    SetMenuItemSelected(menu->selected,FALSE);
 	    if (mrPopup) {
@@ -795,7 +801,7 @@ MenuStatus MenuInteraction(MenuRoot *menu,MenuRoot *menuPrior,
 	  /* must remove previous popup first */
 	  fPopdown = TRUE;
 	}
-	
+
 	if (fPopdown) {
 	  DBUG("MenuInteraction","Popping down");
 	  /* popdown previous popup */
@@ -807,6 +813,8 @@ MenuStatus MenuInteraction(MenuRoot *menu,MenuRoot *menuPrior,
 	}
 	if (fPopup) {
 	  DBUG("MenuInteraction","Popping up");
+          /* get pos hints for item's action */
+          GetPopupOptions(mi,&mops);
 	  mrPopup = MrPopupForMi(mi);
 	  if (!mrPopup) {
 	    fDoMenu = FALSE;
@@ -850,7 +858,7 @@ MenuStatus MenuInteraction(MenuRoot *menu,MenuRoot *menuPrior,
 	  }
 	} /* if (fDoMenu) */
 
-	/* Now check whether we can animate the current popup menu 
+	/* Now check whether we can animate the current popup menu
 	   over to the right to unobscure the current menu;  this
 	   happens only when using animation */
 	tmi = FindEntry(NULL);
@@ -858,7 +866,7 @@ MenuStatus MenuInteraction(MenuRoot *menu,MenuRoot *menuPrior,
 	  (tmi == menu->selected || tmi->mr != menu)) {
 	  int x_popup, y_popup;
 	  DBUG("MenuInteraction","Moving the popup menu back over");
-	  XGetGeometry(dpy, mrPopup->w, &JunkRoot, &x_popup, &y_popup, 
+	  XGetGeometry(dpy, mrPopup->w, &JunkRoot, &x_popup, &y_popup,
 		       &JunkWidth, &JunkHeight, &JunkBW, &JunkDepth);
 	  /* move it back */
 	  AnimatedMoveOfWindow(mrPopup->w,x_popup,y_popup,
@@ -866,7 +874,7 @@ MenuStatus MenuInteraction(MenuRoot *menu,MenuRoot *menuPrior,
 			       FALSE /* no warp ptr */,-1,NULL);
 	  mrPopup->xanimation = 0;
 	}
-	/* now check whether we should animate the current real menu 
+	/* now check whether we should animate the current real menu
 	   over to the right to unobscure the prior menu; only a very
 	   limited case where this might be helpful and not too disruptive */
 	if (mrPopup == NULL && menuPrior != NULL && USING_FVWM_MENUS &&
@@ -874,7 +882,7 @@ MenuStatus MenuInteraction(MenuRoot *menu,MenuRoot *menuPrior,
 	  int x_menu, y_menu;
 	  DBUG("MenuInteraction","Moving the menu back over");
 	  /* we have to see if we need menu to be moved */
-	  XGetGeometry( dpy, menu->w, &JunkRoot, &x_menu, &y_menu, 
+	  XGetGeometry( dpy, menu->w, &JunkRoot, &x_menu, &y_menu,
 			&JunkWidth, &JunkHeight, &JunkBW, &JunkDepth);
 	  /* move it back */
 	  AnimatedMoveOfWindow(menu->w,x_menu,y_menu,
@@ -886,14 +894,14 @@ MenuStatus MenuInteraction(MenuRoot *menu,MenuRoot *menuPrior,
       } /* if (mi) */
       else {
         /* moved off menu, deselect selected item... */
-        if (menu->selected) { 
+        if (menu->selected) {
           SetMenuItemSelected(menu->selected,FALSE);
           if (mrPopup && fOffMenuAllowed == FALSE) {
 	    int x, y, mx, my;
 	    unsigned int mw, mh;
 	    XQueryPointer( dpy, Scr.Root, &JunkRoot, &JunkChild,
 			   &x, &y, &JunkX, &JunkY, &JunkMask);
-	    XGetGeometry( dpy, menu->w, &JunkRoot, &mx, &my, 
+	    XGetGeometry( dpy, menu->w, &JunkRoot, &mx, &my,
 			  &mw, &mh, &JunkBW, &JunkDepth);
 	    if ((!IS_LEFT_MENU(mrPopup)  && x < mx)    ||
 		(!IS_RIGHT_MENU(mrPopup) && x > mx+mw) ||
@@ -911,9 +919,6 @@ MenuStatus MenuInteraction(MenuRoot *menu,MenuRoot *menuPrior,
     } /* while (TRUE) */
 
   DO_RETURN:
-  if (mi) {
-    GetPopupOptions(mi, &mops);
-  }
   if (mrPopup) {
     PopDownMenu(mrPopup);
   }
@@ -945,6 +950,7 @@ MenuStatus MenuInteraction(MenuRoot *menu,MenuRoot *menuPrior,
       pmiExecuteAction && *pmiExecuteAction && (*pmiExecuteAction)->action) {
     f_type = find_func_type((*pmiExecuteAction)->action);
     if (f_type == F_POPUP || f_type == F_STAYSUP || f_type == F_WINDOWLIST) {
+      GetPopupOptions(mi, &mops);
       if (!(mops.flags & MENU_SELECTINPLACE)) {
 	fIgnorePosHints = TRUE;
       } else {
@@ -967,7 +973,7 @@ MenuStatus MenuInteraction(MenuRoot *menu,MenuRoot *menuPrior,
   return MENU_ADD_BUTTON_IF(fKeyPress,retval);
 }
 
-static 
+static
 void WarpPointerToTitle(MenuRoot *menu)
 {
   int y = Scr.EntryHeight/2 + 2;
@@ -982,7 +988,7 @@ MenuItem *MiWarpPointerToItem(MenuItem *mi, Bool fSkipTitle)
   int y;
   int x = MENU_MIDDLE_OFFSET(menu);
 
-  if (fSkipTitle && IS_TITLE_MENU_ITEM(mi) && 
+  if (fSkipTitle && IS_TITLE_MENU_ITEM(mi) &&
       /* also don't skip if there is no next item */
       mi->next != NULL) {
     mi = mi->next;
@@ -1040,8 +1046,6 @@ Bool FPopupMenu (MenuRoot *menu, MenuRoot *menuPrior, int x, int y,
 		 Bool fWarpItem, MenuOptions *pops)
 {
   Bool fWarpTitle = FALSE;
-  Bool fLeft = FALSE;
-  Bool fRight = (pops->flags & MENU_HAS_POSHINTS) ? TRUE : FALSE;
   int x_overlap, x_clipped_overlap;
   MenuItem *mi = NULL;
 
@@ -1063,7 +1067,7 @@ Bool FPopupMenu (MenuRoot *menu, MenuRoot *menuPrior, int x, int y,
     if((Tmp_win)&&(menuPrior == NULL)&&(Context&C_LALL))
       {
 	y = Tmp_win->frame_y+Tmp_win->boundary_width+Tmp_win->title_height+1;
-	x = Tmp_win->frame_x + Tmp_win->boundary_width + 
+	x = Tmp_win->frame_x + Tmp_win->boundary_width +
 	  ButtonPosition(Context,Tmp_win)*Tmp_win->title_height+1;
       }
     if((Tmp_win)&&(menuPrior == NULL)&&(Context&C_RALL))
@@ -1078,12 +1082,11 @@ Bool FPopupMenu (MenuRoot *menu, MenuRoot *menuPrior, int x, int y,
 	if(x < Tmp_win->frame_x + Tmp_win->title_x)
 	  x = Tmp_win->frame_x + Tmp_win->title_x;
 	if((x + menu->width) >
-	   (Tmp_win->frame_x + Tmp_win->title_x +Tmp_win->title_width))	
+	   (Tmp_win->frame_x + Tmp_win->title_x +Tmp_win->title_width))
 	  x = Tmp_win->frame_x + Tmp_win->title_x +Tmp_win->title_width-
 	    menu->width +1;
       }
   } /* if (pops->flags & MENU_HAS_POSHINTS) */
-
   x_overlap = DoMenusOverlap(menuPrior, x, y,menu->width,menu->height, 3);
   /* clip to screen */
   if (x + menu->width > Scr.MyDisplayWidth - 2)
@@ -1169,10 +1172,10 @@ Bool FPopupMenu (MenuRoot *menu, MenuRoot *menuPrior, int x, int y,
 	  fUseLeft = TRUE;
 	else
 	  fUseLeft = FALSE;
-	x = (fUseLeft) ? TRUE : FALSE;
+	x = (fUseLeft) ? left_x : right_x;
       } /* else if (USING_MWM_MENUS || USING_WIN_MENUS) */
     } /* if (x_clipped_overlap && ...) */
-    
+
     if (x < prev_x)
       menu->flags |= MENU_IS_LEFT;
     if (x + menu->width > prev_x + prev_width)
@@ -1184,7 +1187,7 @@ Bool FPopupMenu (MenuRoot *menu, MenuRoot *menuPrior, int x, int y,
     if (!(menu->flags & (MENU_IS_LEFT | MENU_IS_RIGHT)))
       menu->flags |= MENU_IS_LEFT | MENU_IS_RIGHT;
   } /* if (menuPrior) */
-    
+
   /* popup the menu */
   XMoveWindow(dpy, menu->w, x, y);
   XMapRaised(dpy, menu->w);
@@ -1221,7 +1224,7 @@ Bool FPopupMenu (MenuRoot *menu, MenuRoot *menuPrior, int x, int y,
     DBUG("FPopupMenu","Warping to title");
     WarpPointerToTitle(menu);
   }
-  
+
   return True;
 }
 
@@ -1259,6 +1262,8 @@ void GetPopupOptions(MenuItem *mi, MenuOptions *pops)
 {
   char *junk = NULL, *action;
 
+  if (!IS_POPUP_MENU_ITEM(mi))
+    return;
   pops->flags &= ~MENU_HAS_POSHINTS;
   if (mi == NULL)
     return;
@@ -1282,7 +1287,7 @@ void PopDownMenu(MenuRoot *mr)
 {
   MenuItem *mi;
   assert(mr);
-  
+
   mr->flags = 0;
   XUnmapWindow(dpy, mr->w);
 
@@ -1402,18 +1407,18 @@ void PaintEntry(MenuItem *mi)
 		       ReliefGC,ShadowGC);
     RelieveHalfRectangle(mr->w, 0, y_offset, mr->width,
 			 y_height, ReliefGC, ShadowGC);
-  } 
+  }
 
   /* Draw the shadows for the absolute outside of the menus
      This stuff belongs in here, not in PaintMenu, since we only
      want to redraw it when we have too (i.e. on expose event) */
 
   /* Top of the menu */
-  if(mi == mr->first) 
+  if(mi == mr->first)
     DrawSeparator(mr->w,ReliefGC,ReliefGC,0,0, mr->width-1,0,-1);
 
   /* Botton of the menu */
-  if(mi->next == NULL) 
+  if(mi->next == NULL)
     DrawSeparator(mr->w,ShadowGC,ShadowGC,1,mr->height-2,
                   mr->width-2, mr->height-2,1);
 
@@ -1426,7 +1431,7 @@ void PaintEntry(MenuItem *mi)
 		    mr->width-3, y_offset+y_height-2);
 	  XDrawLine(dpy, mr->w, ShadowGC, mr->xoffset+2, y_offset+y_height-4,
 		    mr->width-3, y_offset+y_height-4);
-	}      
+	}
       else if (USING_WIN_MENUS || USING_FVWM_MENUS)
 	{
 	  if(mi->next != NULL)
@@ -1454,10 +1459,10 @@ void PaintEntry(MenuItem *mi)
 	DrawSeparator(mr->w,ShadowGC,ReliefGC,mr->xoffset+5,y_offset-1+HEIGHT_SEPARATOR/2,
 		      mr->width-6,y_offset-1+HEIGHT_SEPARATOR/2,1);
     }
-  if(mi->next == NULL) 
+  if(mi->next == NULL)
     DrawSeparator(mr->w,ShadowGC,ShadowGC,mr->xoffset+1,mr->height-2,
 		  mr->width-2, mr->height-2,1);
-  if(mi == mr->first) 
+  if(mi == mr->first)
     DrawSeparator(mr->w,ReliefGC,ReliefGC,mr->xoffset,0, mr->width-1,0,-1);
 
   if(check_allowed_function(mi))
@@ -1465,7 +1470,7 @@ void PaintEntry(MenuItem *mi)
     currentGC = Scr.MenuGC;
   else
     /* should be a shaded out word, not just re-colored. */
-    currentGC = Scr.MenuStippleGC;    
+    currentGC = Scr.MenuStippleGC;
 
   if (USING_WIN_MENUS && mi->state && (mi->fIsSeparator == FALSE))
     /* Use a lighter color for highlighted windows menu items for win mode */
@@ -1498,7 +1503,7 @@ void PaintEntry(MenuItem *mi)
       x = (mr->width - mi->picture->width)/2;
       if(mi->lpicture && x < mr->width0 + 5)
 	x = mr->width0+5;
-	
+
       if(mi->picture->depth > 0) /* pixmap? */
 	{
 	  Globalgcm = GCClipMask | GCClipXOrigin | GCClipYOrigin;
@@ -1526,7 +1531,7 @@ void PaintEntry(MenuItem *mi)
       int lp_offset = 6;
       if(mi->picture && *mi->item != 0)
 	y = y_offset + mi->y_height - mi->lpicture->height-1;
-      else 
+      else
 	y = y_offset + mi->y_height/2 - mi->lpicture->height/2;
       if(mi->lpicture->depth > 0) /* pixmap? */
 	{
@@ -1566,7 +1571,7 @@ void PaintSidePic(MenuRoot *mr)
     return;
 
   if(Scr.d_depth<2)
-    ReliefGC = Scr.MenuShadowGC; 
+    ReliefGC = Scr.MenuShadowGC;
   else
     ReliefGC = Scr.MenuReliefGC;
   TextGC = Scr.MenuGC;
@@ -1578,14 +1583,14 @@ void PaintSidePic(MenuRoot *mr)
     XFillRectangle(dpy, mr->w, Scr.ScratchGC1, 3, 3,
                    mr->sidePic->width, mr->height - 6);
   }
-    
+
   if(mr->sidePic->depth > 0) /* pixmap? */
     {
       Globalgcm = GCClipMask | GCClipXOrigin | GCClipYOrigin;
       Globalgcv.clip_mask = mr->sidePic->mask;
       Globalgcv.clip_x_origin = 3;
       Globalgcv.clip_y_origin = mr->height - mr->sidePic->height -3;
-      
+
       XChangeGC(dpy,ReliefGC,Globalgcm,&Globalgcv);
       XCopyArea(dpy, mr->sidePic->picture, mr->w,
                 ReliefGC, 0, 0,
@@ -1593,7 +1598,7 @@ void PaintSidePic(MenuRoot *mr)
                 Globalgcv.clip_x_origin, Globalgcv.clip_y_origin);
       Globalgcm = GCClipMask;
       Globalgcv.clip_mask = None;
-      XChangeGC(dpy,ReliefGC,Globalgcm,&Globalgcv);    
+      XChangeGC(dpy,ReliefGC,Globalgcm,&Globalgcv);
     } else {
       XCopyPlane(dpy, mr->sidePic->picture, mr->w,
                  TextGC, 0, 0,
@@ -1615,7 +1620,7 @@ void PaintSidePic(MenuRoot *mr)
  *
  ****************************************************************************/
 static
-void  DrawUnderline(Window w, GC gc, int x, int y, char *txt, int posn) 
+void  DrawUnderline(Window w, GC gc, int x, int y, char *txt, int posn)
 {
   int off1 = XTextWidth(Scr.StdFont.font, txt, posn);
   int off2 = XTextWidth(Scr.StdFont.font, txt, posn + 1) - 1;
@@ -1633,7 +1638,7 @@ void DrawSeparator(Window w, GC TopGC, GC BottomGC,int x1,int y1,int x2,int y2,
   XDrawLine(dpy, w, TopGC   , x1,           y1,  x2,          y2);
   XDrawLine(dpy, w, BottomGC, x1-extra_off, y1+1,x2+extra_off,y2+1);
 }
-    
+
 /****************************************************************************
  *
  *  Draws a little Triangle pattern within a window
@@ -1669,7 +1674,7 @@ void DrawTrianglePattern(Window w,GC GC1,GC GC2,GC GC3,GC gc,int l,int u,int r,i
 void PaintMenu(MenuRoot *mr, XEvent *e)
 {
   MenuItem *mi;
-  
+
   GC ReliefGC;
 
   if(Scr.d_depth<2)
@@ -1719,8 +1724,8 @@ void DestroyMenu(MenuRoot *mr)
     prev->next = mr->next;
 
   XDestroyWindow(dpy,mr->w);
-  XDeleteContext(dpy, mr->w, MenuContext);  
-  
+  XDeleteContext(dpy, mr->w, MenuContext);
+
   if (mr->sidePic)
       DestroyPicture(dpy, mr->sidePic);
 
@@ -1743,10 +1748,10 @@ void DestroyMenu(MenuRoot *mr)
 }
 
 /****************************************************************************
- * 
+ *
  * Generates the windows for all menus
  *
- ****************************************************************************/ 
+ ****************************************************************************/
 void MakeMenus(void)
 {
   MenuRoot *mr;
@@ -1760,10 +1765,10 @@ void MakeMenus(void)
 }
 
 /****************************************************************************
- * 
+ *
  * Generates the window for a menu
  *
- ****************************************************************************/ 
+ ****************************************************************************/
 void MakeMenu(MenuRoot *mr)
 {
   MenuItem *cur;
@@ -1809,11 +1814,11 @@ void MakeMenu(MenuRoot *mr)
   mr->width += 10;
   if(mr->width2 > 0)
     mr->width += 5;
-  
+
   /* cur_prev trails one behind cur, since we need to move that
      into a newly-made menu if we run out of space */
-  for (y=2, cItems = 0, cur = mr->first, cur_prev = NULL; 
-       cur != NULL; 
+  for (y=2, cItems = 0, cur = mr->first, cur_prev = NULL;
+       cur != NULL;
        cur_prev = cur, cur = cur->next, cItems++)
     {
       cur->mr = mr;
@@ -1826,7 +1831,7 @@ void MakeMenu(MenuRoot *mr)
 	    cur->x = (mr->width+mr->width2+mr->width0
 		      - XTextWidth(Scr.StdFont.font, cur->item,
 					     cur->strlen))/2;
-	  
+
 	  if((cur->strlen > 0)||(cur->strlen2>0))
 	    {
 	      if(USING_MWM_MENUS)
@@ -1879,7 +1884,7 @@ void MakeMenu(MenuRoot *mr)
       if (y+Scr.EntryHeight > Scr.MyDisplayHeight &&
 	  cur->next != NULL)
 	{
-	char *szMenuContinuationActionAndName = 
+	char *szMenuContinuationActionAndName =
 	  (char *) safemalloc((8+strlen(mr->name))*sizeof(char));
 	MenuRoot *menuContinuation;
 	if (mr->continuation != NULL) {
@@ -1889,7 +1894,7 @@ void MakeMenu(MenuRoot *mr)
 	strcpy(szMenuContinuationActionAndName,"Popup ");
 	strcat(szMenuContinuationActionAndName, mr->name);
 	strcat(szMenuContinuationActionAndName,"$");
-	/* NewMenuRoot inserts at the head of the list of menus 
+	/* NewMenuRoot inserts at the head of the list of menus
 	   but, we need it at the end */
 	/* (Give it just the name, with is 6 chars passed the action
 	   since strlen("Popup ")==6 ) */
@@ -1912,7 +1917,8 @@ void MakeMenu(MenuRoot *mr)
 	cur = cur_prev;
 
 	/* And add the entry pointing to the new menu */
-	AddToMenu(mr,"More&...",szMenuContinuationActionAndName,FALSE /* no pixmap scan */);
+	AddToMenu(mr,"More&...",szMenuContinuationActionAndName,
+		  FALSE /* no pixmap scan */, FALSE);
 	MakeMenu(menuContinuation);
 
 	}
@@ -1921,8 +1927,8 @@ void MakeMenu(MenuRoot *mr)
   mr->height = y+2;
   mr->flags = 0;
   mr->xanimation = 0;
-  
-#ifndef NO_SAVEUNDERS   
+
+#ifndef NO_SAVEUNDERS
   valuemask = (CWBackPixel | CWEventMask | CWCursor | CWSaveUnder);
 #else
   valuemask = (CWBackPixel | CWEventMask | CWCursor);
@@ -1930,12 +1936,12 @@ void MakeMenu(MenuRoot *mr)
   attributes.background_pixel = Scr.MenuColors.back;
   attributes.event_mask = (ExposureMask | EnterWindowMask);
   attributes.cursor = Scr.FvwmCursors[MENU];
-#ifndef NO_SAVEUNDERS   
+#ifndef NO_SAVEUNDERS
   attributes.save_under = TRUE;
 #endif
   if(mr->w != None)
     XDestroyWindow(dpy,mr->w);
- 
+
   mr->xoffset = 0;
   if(mr->sidePic) {
     mr->xoffset = mr->sidePic->width + 5;
@@ -1949,7 +1955,7 @@ void MakeMenu(MenuRoot *mr)
 			 (Visual *) CopyFromParent,
 			 valuemask, &attributes);
   XSaveContext(dpy,mr->w,MenuContext,(caddr_t)mr);
-  
+
   return;
 }
 
@@ -1979,30 +1985,30 @@ int FHotKeyUsedBefore(MenuRoot *menu, char ch) {
  * Procedure:
  *	scanForHotkeys - Look for hotkey markers in a MenuItem
  * 							(pete@tecc.co.uk)
- * 
+ *
  * Inputs:
  *	it	- MenuItem to scan
  * 	which 	- +1 to look in it->item1 and -1 to look in it->item2.
  *
  ***********************************************************************/
-char scanForHotkeys(MenuItem *it, int which) 
+char scanForHotkeys(MenuItem *it, int which)
 {
   char *start, *txt;
 
   start = (which > 0) ? it->item : it->item2;	/* Get start of string	*/
-  for (txt = start; *txt != '\0'; txt++) 
+  for (txt = start; *txt != '\0'; txt++)
     {
       /* Scan whole string	*/
-      if (*txt == '&') 
+      if (*txt == '&')
 	{		/* A hotkey marker?			*/
-	  if (txt[1] == '&') 
+	  if (txt[1] == '&')
 	    {	/* Just an escaped &			*/
 	      char *tmp;		/* Copy the string down over it	*/
 	      for (tmp = txt; *tmp != '\0'; tmp++) tmp[0] = tmp[1];
 	      continue;		/* ...And skip to the key char		*/
 	    }
 	  else {
-	    char ch = txt[1]; 
+	    char ch = txt[1];
 	    /* It's a hot key marker - work out the offset value */
 	    it->hotkey = (1 + (txt - start)) * which;
 	    for (; *txt != '\0'; txt++) txt[0] = txt[1];	/* Copy down..	*/
@@ -2015,9 +2021,9 @@ char scanForHotkeys(MenuItem *it, int which)
 }
 
 
-/* Side picture support: this scans for a color int the menu name 
+/* Side picture support: this scans for a color int the menu name
    for colorization */
-void scanForColor(char *instring, Pixel *p, Bool *c, char identifier) 
+void scanForColor(char *instring, Pixel *p, Bool *c, char identifier)
 {
   char *tstart, *txt, *save_instring;
   int i;
@@ -2030,14 +2036,14 @@ void scanForColor(char *instring, Pixel *p, Bool *c, char identifier)
   strcpy(save_instring,instring);
 
   /* Scan whole string        */
-  for (txt = instring; *txt != '\0'; txt++) 
+  for (txt = instring; *txt != '\0'; txt++)
     {
       /* A hotkey marker? */
-      if (*txt == identifier) 
+      if (*txt == identifier)
       {
         /* Just an escaped '^'  */
-        if (txt[1] == identifier) 
-          {   
+        if (txt[1] == identifier)
+          {
             char *tmp;                /* Copy the string down over it */
             for (tmp = txt; *tmp != '\0'; tmp++) tmp[0] = tmp[1];
             continue;         /* ...And skip to the key char          */
@@ -2056,7 +2062,7 @@ void scanForColor(char *instring, Pixel *p, Bool *c, char identifier)
 
         *p = GetColor(name);
         *c = True;
-        
+
         if(*txt != '\0')txt++;
         while(*txt != '\0')
           {
@@ -2069,9 +2075,9 @@ void scanForColor(char *instring, Pixel *p, Bool *c, char identifier)
     }
 }
 
-void scanForPixmap(char *instring, Picture **p, char identifier) 
+void scanForPixmap(char *instring, Picture **p, char identifier)
 {
-  char *tstart, *txt, *save_instring;
+  char *tstart, *txt;
   int i;
   Picture *pp;
   char name[100];
@@ -2080,21 +2086,23 @@ void scanForPixmap(char *instring, Picture **p, char identifier)
   extern char *PixmapPath;
 #endif
 
+#ifdef UGLY_WHEN_PIXMAPS_MISSING
+  char *save_instring;
+
   /* save instring in case can't find pixmap */
   save_instring = (char *)safemalloc(strlen(instring)+1);
-#ifdef UGLY_WHEN_PIXMAPS_MISSING
   strcpy(save_instring,instring);
 #endif
 
   /* Scan whole string	*/
-  for (txt = instring; *txt != '\0'; txt++) 
+  for (txt = instring; *txt != '\0'; txt++)
     {
       /* A hotkey marker? */
-      if (*txt == identifier) 
+      if (*txt == identifier)
 	{
 	  /* Just an escaped &	*/
-	  if (txt[1] == identifier) 
-	    {	
+	  if (txt[1] == identifier)
+	    {
 	      char *tmp;		/* Copy the string down over it	*/
 	      for (tmp = txt; *tmp != '\0'; tmp++) tmp[0] = tmp[1];
 	      continue;		/* ...And skip to the key char		*/
@@ -2129,16 +2137,19 @@ void scanForPixmap(char *instring, Picture **p, char identifier)
 	  else
 	    *p=pp;
 #else
-	  if (pp) 
+	  if (pp)
 	      *p=pp;
 	  else {
   	    fvwm_msg(WARN,"scanForPixmap","Couldn't find pixmap %s",name);
 	  }
 #endif
-          free(save_instring);
-	  return;
+	  break;
 	}
     }
+
+#ifdef UGLY_WHEN_PIXMAPS_MISSING
+  free(save_instring);
+#endif
 }
 
 /* FollowMenuContinuations
@@ -2176,20 +2187,17 @@ MenuRoot *FollowMenuContinuations(MenuRoot *mr, MenuRoot **pmrPrior )
  *       so built in window list can handle windows w/ * and % in title.
  *
  ***********************************************************************/
-void AddToMenu(MenuRoot *menu, char *item, char *action, Bool fPixmapsOk)
+void AddToMenu(MenuRoot *menu, char *item, char *action, Bool fPixmapsOk,
+	       Bool fNoPlus)
 {
   MenuItem *tmp;
   char *start,*end;
   char *taction = NULL, *taction2 = NULL;
-  Bool fEmptyItem = FALSE;
-  Bool fEmptyAction = FALSE;
 
   /* Just returning will probably cause a coredump somewhere else, so I think
      we should continue with a default! */
-  /*
-   *  if(item == NULL)
-   *     return;
-   */
+  if ((item == NULL || *item == 0) && fNoPlus)
+    return;
   /* empty items screw up our menu when painted, so we replace them with a
      separator */
   if (item == NULL || *item == 0) item = "";
@@ -2251,7 +2259,7 @@ void AddToMenu(MenuRoot *menu, char *item, char *action, Bool fPixmapsOk)
     {
       start = end+1;
       while(*end != 0)
-	end++;  
+	end++;
       if(end-start != 0)
 	{
 	  tmp->item2 = safemalloc(end-start+1);
@@ -2333,14 +2341,14 @@ void AddToMenu(MenuRoot *menu, char *item, char *action, Bool fPixmapsOk)
  *
  *  Inputs:
  *	name	- the name of the menu root
- *      fFunction - non-zero if we shoot set func to F_FUNCTION, 
+ *      fFunction - non-zero if we shoot set func to F_FUNCTION,
  *                  F_POPUP otherwise
  *
  ***********************************************************************/
 MenuRoot *NewMenuRoot(char *name,int fFunction)
 {
   MenuRoot *tmp;
-  
+
   tmp = (MenuRoot *) safemalloc(sizeof(MenuRoot));
   if(fFunction != 0)
     tmp->func = F_FUNCTION;
@@ -2389,7 +2397,7 @@ int ButtonPosition(int context, FvwmWindow * t)
 {
   int i;
   int buttons = -1;
-  
+
   if (context&C_RALL) {
     for(i=0;i<Scr.nr_right_buttons;i++)
       {
