@@ -1,5 +1,5 @@
-#ifndef _MISC_
-#define _MISC_
+#ifndef MISC_H
+#define MISC_H
 
 #include <ctype.h>
 #include "menus.h"
@@ -31,8 +31,12 @@ typedef struct name_list_struct
   char *Decor;
 #endif
   int Desk;                        /* Desktop number */
-  unsigned long on_flags; 
-  unsigned long off_flags; 
+/* RBW - 11/02/1998 - page x,y numbers */
+  int PageX;
+  int PageY;
+/**/
+  unsigned long on_flags;
+  unsigned long off_flags;
   int border_width;
   int resize_width;
   char *ForeColor;
@@ -190,9 +194,9 @@ extern void       DrawIconWindow(FvwmWindow *);
 extern void       CreateIconWindow(FvwmWindow *tmp_win, int def_x, int def_y);
 
 
-extern FVWM_INLINE void RelieveWindow(FvwmWindow *, Window, 
+extern inline void RelieveWindow(FvwmWindow *, Window,
 				      int, int, int, int, GC, GC, int);
-extern FVWM_INLINE void RelieveWindowHH(FvwmWindow *,Window,
+extern inline void RelieveWindowHH(FvwmWindow *,Window,
 					int,int,int,int, GC,GC, int, int);
 void RelieveParts(FvwmWindow *t,int i,GC hor, GC vert);
 #define NO_HILITE     0x0000
@@ -203,7 +207,6 @@ void RelieveParts(FvwmWindow *t,int i,GC hor, GC vert);
 #define FULL_HILITE   0x000F
 #define HH_HILITE     0x0010
 
-extern void       sleep_a_little(int);
 void Maximize(XEvent *eventp,Window w,FvwmWindow *tmp_win,
 	      unsigned long context, char *action, int *Module);
 #ifdef  WINDOWSHADE
@@ -215,7 +218,7 @@ extern void       LowerWindow(FvwmWindow *t);
 extern Bool       GrabEm(int);
 extern void       UngrabEm(void);
 extern MenuRoot   *NewMenuRoot(char *name, int function_or_popup);
-extern void       AddToMenu(MenuRoot *, char *, char *, Bool);
+extern void       AddToMenu(MenuRoot *, char *, char *, Bool, Bool);
 extern void       MakeMenu(MenuRoot *);
 extern void       CaptureAllWindows(void);
 extern void       SetTimer(int);
@@ -246,25 +249,19 @@ extern void       GetBitmapFile(FvwmWindow *tmp_win);
 extern void       GetXPMFile(FvwmWindow *tmp_win);
 extern void       GetIconWindow(FvwmWindow *tmp_win);
 extern void       GetIconBitmap(FvwmWindow *tmp_win);
-extern void SmartPlacement(FvwmWindow *t, int width, int height,int *x,int *y);
+/*  RBW - 11/02/1998  */
+extern int SmartPlacement(FvwmWindow *t, int width, int height,int *x,int *y, int pdeltax, int pdeltay);
+/**/
 extern void usage(void);
-void Broadcast_v(unsigned long event_type, unsigned long num_datum,...);
-void Broadcast(unsigned long event_type, unsigned long num_datum,
-	       unsigned long data1, unsigned long data2, 
-	       unsigned long data3, unsigned long data4,
-	       unsigned long data5, unsigned long data6, 
-	       unsigned long data7);
-void BroadcastConfig(unsigned long event_type, FvwmWindow *t);
-void SendPacket(int channel, unsigned long event_type, unsigned long num_datum,
-		unsigned long data1, unsigned long data2, 
-		unsigned long data3, unsigned long data4,
-		unsigned long data5, unsigned long data6, 
-		unsigned long data7);
-void SendConfig(int Module, unsigned long event_type, FvwmWindow *t);
+void BroadcastPacket(unsigned long event_type, unsigned long num_datum, ...);
+void SendPacket(int channel, unsigned long event_type,
+                unsigned long num_datum, ...);
+void BroadcastConfig(unsigned long event_type, const FvwmWindow *t);
+void SendConfig(int Module, unsigned long event_type, const FvwmWindow *t);
 void BroadcastName(unsigned long event_type, unsigned long data1,
-		   unsigned long data2, unsigned long data3, char *name);
-void SendName(int channel, unsigned long event_type,unsigned long data1,
-	      unsigned long data2, unsigned long data3, char *name);
+		   unsigned long data2, unsigned long data3, const char *name);
+void SendName(int channel, unsigned long event_type, unsigned long data1,
+	      unsigned long data2, unsigned long data3, const char *name);
 void SendStrToModule(XEvent *eventp,Window junk,FvwmWindow *tmp_win,
                      unsigned long context, char *action,int* Module);
 void DeadPipe(int nonsense);
@@ -299,7 +296,9 @@ void show_panner(void);
 void WaitForButtonsUp(void);
 void FocusOn(FvwmWindow *t,int DeIconifyOnly);
 void WarpOn(FvwmWindow *t,int warp_x, int x_unit, int warp_y, int y_unit);
-Bool PlaceWindow(FvwmWindow *tmp_win, unsigned long flags,int Desk);
+/*  RBW - 11/02/1998  */
+Bool PlaceWindow(FvwmWindow *tmp_win, unsigned long flags,
+                 int Desk, int PageX, int PageY);
 void free_window_names (FvwmWindow *tmp, Bool nukename, Bool nukeicon);
 
 MenuStatus do_menu (MenuRoot *menu,MenuRoot *menuPrior,
@@ -348,7 +347,7 @@ void SetColormapFocus(XEvent *eventp,Window w,FvwmWindow *tmp_win,
 		      unsigned long context, char *action,int* Module);
 void SetColorLimit(XEvent *eventp,Window w,FvwmWindow *tmp_win,
 		      unsigned long context, char *action,int* Module);
-FVWM_INLINE void DrawPattern(Window, GC, GC, int, int,int);
+
 Pixel    GetShadow(Pixel);
 Pixel    GetHilite(Pixel);
 
@@ -541,6 +540,8 @@ void AddModConfig(XEvent *eventp,Window junk,FvwmWindow *tmp_win,
 void SetEnv(XEvent *eventp,Window junk,FvwmWindow *tmp_win,
 	    unsigned long context, char *action,int* Module);
 
+void CoerceEnterNotifyOnCurrentWindow();
+
 /*
 ** message levels for fvwm_msg:
 */
@@ -550,14 +551,5 @@ void SetEnv(XEvent *eventp,Window junk,FvwmWindow *tmp_win,
 #define ERR  2
 void fvwm_msg(int type,char *id,char *msg,...);
 
-#ifdef BROKEN_SUN_HEADERS
-#include "sun_headers.h"
-#endif
-#ifdef NEEDS_ALPHA_HEADER
-#include "alpha_header.h"
-#endif /* NEEDS_ALPHA_HEADER */
-#endif /* _MISC_ */
+#endif /* MISC_H */
 
-#ifndef HAVE_USLEEP
-int usleep (unsigned long usec);
-#endif
