@@ -1,6 +1,6 @@
 /*
- * This module is all original code 
- * by Rob Nation 
+ * This module is all original code
+ * by Rob Nation
  * Copyright 1993, Robert Nation
  *     You may use this code for any purpose, as long as the original
  *     copyright remains in the source code and all documentation
@@ -17,6 +17,7 @@
 #include <stdio.h>
 #include <signal.h>
 #include <string.h>
+#include <unistd.h>
 #include <X11/keysym.h>
 #include "fvwm.h"
 #include "menus.h"
@@ -32,14 +33,15 @@ Bool NeedToResizeToo;
 /* Animated move stuff added by Greg J. Badros, gjb@cs.washington.edu */
 
 float rgpctMovementDefault[32] = {
-    -.01, 0, .01, .03,.08,.18,.3,.45,.60,.75,.85,.90,.94,.97,.99,1.0 
+    -.01, 0, .01, .03,.08,.18,.3,.45,.60,.75,.85,.90,.94,.97,.99,1.0
     /* must end in 1.0 */
   };
 
 int cmsDelayDefault = 10; /* milliseconds */
 
 /* Perform the movement of the window. ppctMovement *must* have a 1.0 entry
-   somewhere in ins list of floats, and movement will stop when it hits a 1.0 entry */
+ * somewhere in ins list of floats, and movement will stop when it hits a 1.0
+ * entry */
 void AnimatedMoveOfWindow(Window w,int startX,int startY,int endX, int endY,
 			  Bool fWarpPointerToo, int cmsDelay, float *ppctMovement )
 {
@@ -52,9 +54,9 @@ void AnimatedMoveOfWindow(Window w,int startX,int startY,int endX, int endY,
   if (ppctMovement == NULL) ppctMovement = rgpctMovementDefault;
   if (cmsDelay < 0)         cmsDelay     = cmsDelayDefault;
 
-  if (startX < 0 || startY < 0) 
+  if (startX < 0 || startY < 0)
     {
-    XGetGeometry(dpy, w, &JunkRoot, &currentX, &currentY, 
+    XGetGeometry(dpy, w, &JunkRoot, &currentX, &currentY,
 		 &JunkWidth, &JunkHeight, &JunkBW, &JunkDepth);
     if (startX < 0) startX = currentX;
     if (startY < 0) startY = currentY;
@@ -65,6 +67,7 @@ void AnimatedMoveOfWindow(Window w,int startX,int startY,int endX, int endY,
   lastX = startX;
   lastY = startY;
 
+  if (deltaX == 0 && deltaY == 0) return; /* go nowhere fast */
   do {
     currentX = startX + deltaX * (*ppctMovement);
     currentY = startY + deltaY * (*ppctMovement);
@@ -83,7 +86,7 @@ void AnimatedMoveOfWindow(Window w,int startX,int startY,int endX, int endY,
     /* this didn't work for me -- maybe no longer necessary since
        we warn the user when they use > .5 seconds as a between-frame delay
        time */
-    if (XCheckMaskEvent(dpy, 
+    if (XCheckMaskEvent(dpy,
 			ButtonPressMask|ButtonReleaseMask|
 			KeyPressMask,
 			&Event)) {
@@ -97,7 +100,7 @@ void AnimatedMoveOfWindow(Window w,int startX,int startY,int endX, int endY,
     lastY = currentY;
     }
   while (*ppctMovement != 1.0 && ppctMovement++);
- 
+
 }
 
 
@@ -133,37 +136,39 @@ void move_window_doit(XEvent *eventp,Window w,FvwmWindow *tmp_win,
 	w = tmp_win->icon_w;
     }
 
-  XGetGeometry(dpy, w, &JunkRoot, &x, &y, 
+  XGetGeometry(dpy, w, &JunkRoot, &x, &y,
 	       &width, &height, &JunkBW, &JunkDepth);
   if (fMoveToPage)
     {
       fAnimated = FALSE;
-      if (GetTwoArguments(action, &page_x, &page_y, &unit_x, &unit_y) != 2)
+      FinalX = x % Scr.MyDisplayWidth;
+      FinalY = y % Scr.MyDisplayHeight;
+      if (GetTwoArguments(action, &page_x, &page_y, &unit_x, &unit_y) == 2)
 	{
-	  fvwm_msg(ERR,"move_window_doit","MoveToPage requires two arguments");
-	  return;
+	  if (unit_x != Scr.MyDisplayWidth || unit_y != Scr.MyDisplayHeight)
+	    {
+	      fvwm_msg(ERR,"move_window_doit",
+		       "MoveToPage arguments should be unitless");
+	    }
+	  if (page_x < 0 || page_y < 0 ||
+	      page_x*Scr.MyDisplayWidth > Scr.VxMax ||
+	      page_y*Scr.MyDisplayHeight > Scr.VyMax)
+	    {
+	      fvwm_msg(ERR,"move_window_doit",
+		       "MoveToPage: invalid page number");
+	      return;
+	    }
+	  tmp_win->flags &= ~STICKY;
+	  FinalX += page_x*Scr.MyDisplayWidth - Scr.Vx;
+	  FinalY += page_y*Scr.MyDisplayHeight - Scr.Vy;
 	}
-      if (unit_x != Scr.MyDisplayWidth || unit_y != Scr.MyDisplayHeight)
-	{
-	  fvwm_msg(ERR,"move_window_doit",
-		   "MoveToPage arguments should be unitless");
-	}
-      if (page_x < 0 || page_y < 0 || page_x*Scr.MyDisplayWidth > Scr.VxMax ||
-	  page_y*Scr.MyDisplayHeight > Scr.VyMax)
-	{
-	  fvwm_msg(ERR,"move_window_doit","MoveToPage: invalid page number");
-	  return;
-	}
-      tmp_win->flags &= ~STICKY;
-      FinalX = (x % Scr.MyDisplayWidth) + page_x*Scr.MyDisplayWidth - Scr.Vx;
-      FinalY = (y % Scr.MyDisplayHeight) + page_y*Scr.MyDisplayHeight - Scr.Vy;
     }
   else
     {
       n = GetPositionArguments(action,x,y,width+tmp_win->bw,
 			       height+tmp_win->bw,&FinalX,&FinalY);
       if (n != 2)
-	InteractiveMove(&w,tmp_win,&FinalX,&FinalY,eventp);      
+	InteractiveMove(&w,tmp_win,&FinalX,&FinalY,eventp);
     }
 
   if (w == tmp_win->frame)
@@ -180,17 +185,18 @@ void move_window_doit(XEvent *eventp,Window w,FvwmWindow *tmp_win,
       tmp_win->icon_x_loc = FinalX ;
       tmp_win->icon_xl_loc = FinalX -
 	    (tmp_win->icon_w_width - tmp_win->icon_p_width)/2;
-      tmp_win->icon_y_loc = FinalY; 
-      Broadcast(M_ICON_LOCATION,7,tmp_win->w,tmp_win->frame,
-		(unsigned long)tmp_win,
-		tmp_win->icon_x_loc,tmp_win->icon_y_loc,
-		tmp_win->icon_w_width, tmp_win->icon_w_height
-		+tmp_win->icon_p_height);
+      tmp_win->icon_y_loc = FinalY;
+      BroadcastPacket(M_ICON_LOCATION, 7,
+                      tmp_win->w, tmp_win->frame,
+                      (unsigned long)tmp_win,
+                      tmp_win->icon_x_loc, tmp_win->icon_y_loc,
+                      tmp_win->icon_w_width,
+                      tmp_win->icon_w_height + tmp_win->icon_p_height);
       if (fAnimated) {
         AnimatedMoveOfWindow(tmp_win->icon_w,-1,-1,tmp_win->icon_xl_loc,FinalY+tmp_win->icon_p_height,
 			     TRUE,-1,NULL);
       } else {
-        XMoveWindow(dpy,tmp_win->icon_w, 
+        XMoveWindow(dpy,tmp_win->icon_w,
 		    tmp_win->icon_xl_loc, FinalY+tmp_win->icon_p_height);
       }
       if(tmp_win->icon_pixmap_w != None)
@@ -204,9 +210,9 @@ void move_window_doit(XEvent *eventp,Window w,FvwmWindow *tmp_win,
 	  }
 	  XMapWindow(dpy,w);
 	}
-      
+
     }
-  
+
   return;
 }
 
@@ -262,10 +268,10 @@ void moveLoop(FvwmWindow *tmp_win, int XOffset, int YOffset, int Width,
       /* block until there is an interesting event */
       XMaskEvent(dpy, ButtonPressMask | ButtonReleaseMask | KeyPressMask |
 		 PointerMotionMask | ButtonMotionMask | ExposureMask, &Event);
-      StashEventTime(&Event);      
+      StashEventTime(&Event);
 
       /* discard any extra motion events before a logical release */
-      if (Event.type == MotionNotify) 
+      if (Event.type == MotionNotify)
 	{
 	  while(XCheckMaskEvent(dpy, PointerMotionMask | ButtonMotionMask |
 				ButtonPressMask |ButtonRelease, &Event))
@@ -376,14 +382,14 @@ void moveLoop(FvwmWindow *tmp_win, int XOffset, int YOffset, int Width,
 		  tmp_win->icon_x_loc = xl ;
 		  tmp_win->icon_xl_loc = xl -
 		    (tmp_win->icon_w_width - tmp_win->icon_p_width)/2;
-		  tmp_win->icon_y_loc = yt; 
+		  tmp_win->icon_y_loc = yt;
 		  if(tmp_win->icon_pixmap_w != None)
 		    XMoveWindow (dpy, tmp_win->icon_pixmap_w,
 				 tmp_win->icon_x_loc,yt);
                   else if (tmp_win->icon_w != None)
 		    XMoveWindow(dpy, tmp_win->icon_w,tmp_win->icon_xl_loc,
 				yt+tmp_win->icon_p_height);
-		    
+
 		}
 	      else
 		XMoveWindow(dpy,tmp_win->frame,xl,yt);
@@ -442,7 +448,7 @@ void DisplayPosition (FvwmWindow *tmp_win, int x, int y,int Init)
 {
   char str [100];
   int offset;
-  
+
   (void) sprintf (str, " %+-4d %+-4d ", x, y);
   if(Init)
     {
@@ -470,22 +476,26 @@ void DisplayPosition (FvwmWindow *tmp_win, int x, int y,int Init)
 
 /****************************************************************************
  *
- * For menus, move, and resize operations, we can effect keyboard 
+ * For menus, move, and resize operations, we can effect keyboard
  * shortcuts by warping the pointer.
  *
  ****************************************************************************/
-void Keyboard_shortcuts(XEvent *Event, int ReturnEvent)  
+void Keyboard_shortcuts(XEvent *Event, int ReturnEvent)
 {
   int x,y,x_root,y_root;
-  int move_size,x_move,y_move;
+  int x_move_size,y_move_size,x_move,y_move;
   KeySym keysym;
 
-  /* Pick the size of the cursor movement */
-  move_size = Scr.EntryHeight;
+  /* Pick the size of the cursor movement, window resize increments are first
+     choice followed by height of a menu item */
+  x_move_size = Scr.Hilite->hints.width_inc;
+  y_move_size = Scr.Hilite->hints.height_inc;
+  if (y_move_size < 5) y_move_size = Scr.EntryHeight;
+  if (x_move_size < 5) x_move_size = y_move_size;
   if(Event->xkey.state & ControlMask)
-    move_size = 1;
+    x_move_size = y_move_size = 1;
   if(Event->xkey.state & ShiftMask)
-    move_size = 100;
+    x_move_size = y_move_size = 100;
 
   keysym = XLookupKeysym(&Event->xkey,0);
 
@@ -494,26 +504,47 @@ void Keyboard_shortcuts(XEvent *Event, int ReturnEvent)
   switch(keysym)
     {
     case XK_Up:
+    case XK_KP_8:
     case XK_k:
     case XK_p:
-      y_move = -move_size;
+      y_move = -y_move_size;
       break;
     case XK_Down:
+    case XK_KP_2:
     case XK_n:
     case XK_j:
-      y_move = move_size;
+      y_move = y_move_size;
       break;
     case XK_Left:
+    case XK_KP_4:
     case XK_b:
     case XK_h:
-      x_move = -move_size;
+      x_move = -x_move_size;
       break;
     case XK_Right:
+    case XK_KP_6:
     case XK_f:
     case XK_l:
-      x_move = move_size;
+      x_move = x_move_size;
+      break;
+    case XK_KP_1:
+      x_move = -x_move_size;
+      y_move = y_move_size;
+      break;
+    case XK_KP_3:
+      x_move = x_move_size;
+      y_move = y_move_size;
+      break;
+    case XK_KP_7:
+      x_move = -x_move_size;
+      y_move = -y_move_size;
+      break;
+    case XK_KP_9:
+      x_move = x_move_size;
+      y_move = -y_move_size;
       break;
     case XK_Return:
+    case XK_KP_Enter:
     case XK_space:
       /* beat up the event */
       Event->type = ReturnEvent;
@@ -553,11 +584,11 @@ void InteractiveMove(Window *win, FvwmWindow *tmp_win, int *FinalX, int *FinalY,
   Window w;
 
   Bool opaque_move = False;
-  
+
   w = *win;
- 
+
   InstallRootColormap();
-  if (menuFromFrameOrWindowOrTitlebar) 
+  if (menuFromFrameOrWindowOrTitlebar)
     {
       /* warp the pointer to the cursor position from before menu appeared*/
       /* FIXGJB: XWarpPointer(dpy, None, Scr.Root, 0, 0, 0, 0, Stashed_X,Stashed_Y); */
@@ -567,20 +598,19 @@ void InteractiveMove(Window *win, FvwmWindow *tmp_win, int *FinalX, int *FinalY,
 
   DragX = eventp->xbutton.x_root;
   DragY = eventp->xbutton.y_root;
-  /* If this is left commented out, then the move starts from the button press 
-   * location instead of the current location, which seems to be an
-   * improvement */
-  /*  XQueryPointer(dpy, Scr.Root, &JunkRoot, &JunkChild,
-      &DragX, &DragY,	&JunkX, &JunkY, &JunkMask);*/
+  /* If this is commented out, then the move starts from the button press
+   * location instead of the current location */
+  XQueryPointer(dpy, Scr.Root, &JunkRoot, &JunkChild,
+      &DragX, &DragY,	&JunkX, &JunkY, &JunkMask);
 
   if(!GrabEm(MOVE))
     {
-      XBell(dpy,Scr.screen);
+      XBell(dpy, 0);
       return;
     }
 
   XGetGeometry(dpy, w, &JunkRoot, &origDragX, &origDragY,
-	       (unsigned int *)&DragWidth, (unsigned int *)&DragHeight, 
+	       (unsigned int *)&DragWidth, (unsigned int *)&DragHeight,
 	       &JunkBW,  &JunkDepth);
 
   if(DragWidth*DragHeight <
@@ -588,7 +618,7 @@ void InteractiveMove(Window *win, FvwmWindow *tmp_win, int *FinalX, int *FinalY,
     opaque_move = True;
   else
     MyXGrabServer(dpy);
-  
+
   if((!opaque_move)&&(tmp_win->flags & ICONIFIED))
     XUnmapWindow(dpy,w);
 
