@@ -6,11 +6,29 @@
 #include <X11/Xresource.h>
 #include <ctype.h>
 
+/***********************************************************************
+ * Generic debugging
+ ***********************************************************************/
+
+#ifndef DEBUG
+# define DB(_x)
+#else
+# ifndef __FILE__
+#  define __FILE__ "?"
+#  define __LINE__ 0
+# endif
+# define DB(_x) do{f_db_info.filenm=__FILE__;f_db_info.lineno=__LINE__;\
+                   f_db_print _x;}while(0)
+struct f_db_info { const char *filenm; unsigned long lineno; };
+extern struct f_db_info f_db_info;
+extern void f_db_print(const char *fmt, ...);
+#endif
+
+
 /***********************************************************************
  * Routines for dealing with strings
  ***********************************************************************/
-int mystrcasecmp(char *a, char *b);
-int mystrncasecmp(char *a, char *b,int n);
+
 char *CatString3(char *a, char *b, char *c);
 void CopyString(char **dest, char *source);
 char *stripcpy(char *source);
@@ -48,13 +66,10 @@ char *GetNextTokenIndex(char *action, char *list[], int len, int *index);
 /***********************************************************************
  * Various system related utils
  ***********************************************************************/
-int mygethostname(char *client, int namelen);
+
 int GetFdWidth(void);
-
 char *safemalloc(int);
 
-void sleep_a_little(int n);
-
 /***********************************************************************
  * Stuff for modules to communicate with fvwm
  ***********************************************************************/
@@ -80,7 +95,7 @@ typedef struct PictureThing
 } Picture;
 
 void InitPictureCMap(Display*,Window);
-Picture *GetPicture(Display* dpy, Window Root, char* IconPath, 
+Picture *GetPicture(Display* dpy, Window Root, char* IconPath,
 		    char* PixmapPath, char* name, int color_limit);
 Picture *CachePicture(Display*,Window,char *iconpath,
                       char *pixmappath,char*,int);
