@@ -1,3 +1,20 @@
+/* 
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ */
+
+
 /***************************************************************************
  * FvwmBanner                                                           
  *                                                                           
@@ -33,16 +50,8 @@
 #include <X11/xpm.h>
 
 
-#ifdef BROKEN_SUN_HEADERS
-#include "../../fvwm/sun_headers.h"
-#endif
-
 #include "../../libs/fvwmlib.h"     
 
-#ifdef NEEDS_ALPHA_HEADER
-#include "../../fvwm/alpha_header.h"
-#endif /* NEEDS_ALPHA_HEADER */
-
 #include "../../icons/fvwm2_big.xpm"
 #if 0
 #include "../../icons/k2.xpm"
@@ -211,7 +220,7 @@ int main(int argc, char **argv)
   XMapWindow(dpy,win);
   XSync(dpy,0);
 #if 0
-  sleep_a_little(timeout);
+  usleep(timeout);
 #else
   XSelectInput(dpy,win,ButtonReleaseMask);
   /* Display the window */
@@ -325,7 +334,7 @@ static void parseOptions (int fd[2])
   {
     if (strlen (tline) > 1)
     {
-      if (mystrncasecmp (tline,
+      if (strncasecmp (tline,
 			 CatString3 ("*", myName, "Pixmap"),
 			 clength + 7) ==0)
       {
@@ -340,14 +349,14 @@ static void parseOptions (int fd[2])
 	}
         continue;
       }
-      if (mystrncasecmp (tline,
+      if (strncasecmp (tline,
 			 CatString3 ("*", myName, "Timeout"),
 			 clength + 8) ==0)
       {
         timeout = atoi(&tline[clength+8]) * 1000000;
         continue;
       }
-      if (mystrncasecmp(tline, "PixmapPath",10)==0)
+      if (strncasecmp(tline, "PixmapPath",10)==0)
       {
         CopyString (&pixmapPath, &tline[10]);
         if (pixmapPath[0] == 0)
