@@ -4,7 +4,7 @@
 #include "readconfig.h"
 
 static char const rcsid[] =
-  "$Id: readconfig.c,v 1.2 1998/10/30 21:19:45 domivogt Exp $";
+  "$Id: readconfig.c,v 1.5 1998/11/06 17:53:52 domivogt Exp $";
 
 /************************************************************************
  *
@@ -222,29 +222,6 @@ static void skip_space (char **p)
     (*p)++;
 }
 
-static char *stripcpy(char *source)
-{
-  char *tmp,*ptr;
-  int len;
-
-  if(source == NULL)
-    return NULL;
-
-  while(isspace(*source))
-    source++;
-  len = strlen(source);
-  tmp = source + len -1;
-  while(((isspace(*tmp))||(*tmp == '\n'))&&(tmp >=source))
-    {
-      tmp--;
-      len--;
-    }
-  ptr = safemalloc(len+1);
-  strncpy(ptr,source,len);
-  ptr[len]=0;
-  return ptr;
-}
-
 static void add_to_binding (Binding **list, Binding *binding)
 {
   ConsoleDebug (CONFIG, "In add_to_binding:\n");
@@ -303,7 +280,7 @@ static int extract_int (char *p, int *n)
 
 /* I modified this from the fvwm version to stop at commas */
 
-static char *GetNextToken(char *indata,char **token)
+static char *internal_GetNextToken(char *indata,char **token)
 { 
   char *t,*start, *end, *text;
 
@@ -456,7 +433,7 @@ static char *parse_button (char *string, BuiltinArg *arg, int *flag)
   bv->offset = 0;
   bv->base = AbsoluteButton;
 
-  rest = GetNextToken (string, &token);
+  rest = internal_GetNextToken (string, &token);
   if (token == NULL || !strcmp (token, ",")) {
     bv->base = NoButton;
     *flag = 0;
@@ -560,7 +537,7 @@ static Function *parse_function (char **line)
 
   ConsoleDebug (CONFIG, "in parse_function\n");
 
-  ptr = GetNextToken (*line, &name);
+  ptr = internal_GetNextToken (*line, &name);
   if (name == NULL || name[0] == '\0') {
     *line = NULL;
     Free (name);
@@ -580,7 +557,7 @@ static Function *parse_function (char **line)
       ftype->args[j].type = builtin_functions_i->args[j];
       switch (builtin_functions_i->args[j]) {
       case IntArg:
-	ptr = GetNextToken (ptr, &tok);
+	ptr = internal_GetNextToken (ptr, &tok);
 	if (!tok) {
 	  ConsoleMessage ("%s: too few arguments\n",
 			  builtin_functions_i->name);
@@ -598,7 +575,7 @@ static Function *parse_function (char **line)
 	break;
 	
       case StringArg:
-	ptr = GetNextToken (ptr, &ftype->args[j].value.string_value);
+	ptr = internal_GetNextToken (ptr, &ftype->args[j].value.string_value);
 	if (!ftype->args[j].value.string_value || 
 	    !strcmp (ftype->args[j].value.string_value, ",")) {
 	  ConsoleMessage ("%s: too few arguments\n",
@@ -631,7 +608,7 @@ static Function *parse_function (char **line)
 	 * jump offsets at compile time.
 	 */
       case JmpArg:
-	ptr = GetNextToken (ptr, &tok);
+	ptr = internal_GetNextToken (ptr, &tok);
 	if (!tok) {
 	  ConsoleMessage ("%s: too few arguments\n",
 			  builtin_functions_i->name);
@@ -721,7 +698,7 @@ static Function *parse_function_list (char *line)
       f->prev=tail;
       tail = f;
     }
-    p = GetNextToken (line, &token);
+    p = internal_GetNextToken (line, &token);
     if (token && token[0] && strcmp (token, ",") != 0) {
       ConsoleMessage ("Bad function list, comma expected\n");
       Free (token);
@@ -770,13 +747,13 @@ Binding *ParseMouseEntry (char *tline)
 
   /* tline points after the key word "key" */
   ptr = tline;
-  ptr = GetNextToken(ptr,&token);  
+  ptr = internal_GetNextToken(ptr,&token);  
   if(token != NULL) {
     n1 = sscanf(token,"%d",&button);
     Free(token);
   }
 
-  action = GetNextToken(ptr,&token); 
+  action = internal_GetNextToken(ptr,&token); 
   if(token != NULL) {
     n2 = sscanf(token,"%19s",modifiers);
     Free(token);
@@ -825,13 +802,13 @@ static Binding *ParseKeyEntry (char *tline)
   /* tline points after the key word "key" */
   ptr = tline;
 
-  ptr = GetNextToken(ptr,&token);  
+  ptr = internal_GetNextToken(ptr,&token);  
   if(token != NULL) {
     n1 = sscanf(token,"%19s",key);
     Free(token);
   }
   
-  action = GetNextToken(ptr,&token);  
+  action = internal_GetNextToken(ptr,&token);  
   if(token != NULL) {
     n2 = sscanf(token,"%19s",modifiers);
     Free(token);
@@ -1354,7 +1331,7 @@ void read_in_resources (char *file)
 	  ConsoleMessage ("Bad line: %s\n", current_line);
 	  continue;
 	}
-	p = GetNextToken (p, &token);
+	p = internal_GetNextToken (p, &token);
 	if (!token || !token[0]) {
 	  ConsoleMessage ("Bad line: %s\n", current_line);
 	  continue;
@@ -1370,7 +1347,7 @@ void read_in_resources (char *file)
 	    add_to_stringlist (&globals.managers[manager].dontshow, token);
 	  }
 	  Free (token);
-	  p = GetNextToken (p, &token);
+	  p = internal_GetNextToken (p, &token);
 	} while (token && token[0]);
 	if (token)
 	  Free(token);
@@ -1458,7 +1435,7 @@ void read_in_resources (char *file)
 	  ConsoleMessage ("Bad line: %s\n", current_line);
 	  continue;
 	}
-	GetNextToken (p, &token);
+	internal_GetNextToken (p, &token);
 	
 	SET_MANAGER (manager, formatstring,
 		     copy_string (&globals.managers[id].formatstring, token));
@@ -1477,7 +1454,7 @@ void read_in_resources (char *file)
 	  ConsoleMessage ("Bad line: %s\n", current_line);
 	  continue;
 	}
-	GetNextToken (p, &token);
+	internal_GetNextToken (p, &token);
 	
 	SET_MANAGER (manager, iconname,
 		     copy_string (&globals.managers[id].iconname, token));
@@ -1546,7 +1523,7 @@ void read_in_resources (char *file)
 	  ConsoleMessage ("Bad line: %s\n", current_line);
 	  continue;
 	}
-	p = GetNextToken (p, &token);
+	p = internal_GetNextToken (p, &token);
 	if (!token || !token[0]) {
 	  ConsoleMessage ("Bad line: %s\n", current_line);
 	  continue;
@@ -1562,7 +1539,7 @@ void read_in_resources (char *file)
 	    add_to_stringlist (&globals.managers[manager].show, token);
 	  }
 	  Free (token);
-	  p = GetNextToken (p, &token);
+	  p = internal_GetNextToken (p, &token);
 	} while (token && token[0]);
 	if (token)
 	  Free(token);
@@ -1613,7 +1590,7 @@ void read_in_resources (char *file)
 	  ConsoleMessage ("Bad line: %s\n", current_line);
 	  continue;
 	}
-	GetNextToken (p, &token);
+	internal_GetNextToken (p, &token);
 	
 	SET_MANAGER (manager, titlename,
 		     copy_string (&globals.managers[id].titlename, token));
