@@ -80,7 +80,7 @@ char id[15], desktop[10], swidth[10], sheight[10], borderw[10], geometry[30];
  *	main - start of module
  *
  ***********************************************************************/
-void main(int argc, char **argv)
+int main(int argc, char **argv)
 {
   char *temp, *s;
   FILE *file;
@@ -142,16 +142,16 @@ void main(int argc, char **argv)
     {
       if(strlen(tline)>1)
 	{
-	  if(mystrncasecmp(tline, CatString3(MyName,"Font",""),Clength+4)==0)
+	  if(strncasecmp(tline, CatString3(MyName,"Font",""),Clength+4)==0)
 	    {
 	      CopyString(&font_string,&tline[Clength+4]);
 	    }
-	  else if(mystrncasecmp(tline,CatString3(MyName,"Fore",""),
+	  else if(strncasecmp(tline,CatString3(MyName,"Fore",""),
 				Clength+4)==0)
 	    {
 	      CopyString(&ForeColor,&tline[Clength+4]);
 	    }
-	  else if(mystrncasecmp(tline,CatString3(MyName, "Back",""),
+	  else if(strncasecmp(tline,CatString3(MyName, "Back",""),
 				Clength+4)==0)
 	    {
 	      CopyString(&BackColor,&tline[Clength+4]);
@@ -486,7 +486,7 @@ void GetTargetWindow(Window *app_win)
 		       CurrentTime);
       if(val != GrabSuccess)
 	{
-	  sleep_a_little(1000);
+	  usleep(1000);
 	}
       trials++;
     }
